SC Judicial Department
Keywords: Courts, South Carolina, web, Judiciary, legal, state, judicial, court, Supreme Court, Court of Appeals

South Carolina
JUDICIAL DEPARTMENT
Text Only Page
Site Map | Feedback
Search:

Supreme Court Published Opinions - May 2014

Note: Beginning in June 2012, opinions will be posted as Adobe PDFs. You can download a free copy of Adobe Reader here.

The summary following each opinion is prepared to offer lawyers and the public a general overview of what a particular opinion decides. The summary is not necessarily a full description of the issues discussed in an opinion.

5-14-2014 - Opinions

27387 - York County v. SCDHEC

> This case is dismissed as improvidently granted.

© 2000-2014 South Carolina Judicial Department
2014
January
February
March
April
May
June
July
August
September
October
November
December
2013
January
February
March
April
May
June
July
August
September
October
November
December
2012
January
February
March
April
May
June
July
August
September
October
November
December
2011
January
February
March
April
May
June
July
August
September
October
November
December
2010
January
February
March
April
May
June
July
August
September
October
November
December
2009
January
February
March
April
May
June
July
August
September
October
November
December
2008
January
February
March
April
May
June
July
August
September
October
November
December
2007
January
February
March
April
May
June
July
August
September
October
November
December
2006
January
February
March
April
May
June
July
August
September
October
November
December
2005
January
February
March
April
May
June
July
August
September
October
November
December
2004
January
February
March
April
May
June
July
August
September
October
November
December
2003
January
February
March
April
May
June
July
August
September
October
November
December
2002
January
February
March
April
May
June
July
August
September
October
November
December
2001
January
February
March
April
May
June
July
August
September
October
November
December
2000
January
February
March
April
May
June
July
August
September
October
November
December
1999
January
February
March
April
May
June
July
August
September
October
November
December
1998
January
February
March
April
May
June
July
August
September
October
November
December
1997
January
February
March
April
May
June
July
August
September
October
November
December